import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, nest,scaleLinear,scaleBand,scaleLog, max, format, extent,ascending } from 'd3';
import ReactDropdown from 'react-dropdown';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';
import { Slider } from './slider'

const width = 960;
const menuHeight = 80;
const height = 500 - menuHeight;
const margin = { top: 80, right: 30, bottom:20, left: 120 };
const xAxisLabelOffset = 50;
const yAxisLabelOffset = 45;


const minDay = 1;
const maxDay = 31;
const dayStep = 1;

const App = () => {
  const data = useData();

  const initialDay = 31;
  const [day, setDay] = useState(initialDay);
  
  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  const siFormat = format('.2s');
  const xAxisTickFormat = tickValue => siFormat(tickValue).replace('G', 'B');

  
  
  const filteredData = data.filter(d => d.Dateofmonth == day);

  console.log(filteredData)
 
  filteredData.sort(function(a, b){
    return a["deaths"]-b["deaths"];
});
  
 const yScale = scaleBand()
	 .domain(filteredData.map(d => d.location))
   .range([ innerHeight,0])
   .paddingInner(0.15)

 
  const xScale = scaleLinear()
   .domain([0,1000])
  .range([0, innerWidth]);
 
  
	  const yValue = d => d.location;
 // const xValue = d => d.total_cases;
 const xValue = d => d.deaths;
	
 const sliderHidden ='visible'
    
 return (
    <>
     <svg width={width} height={height}>
        <g transform={`translate(${margin.left},${margin.top})`}>
          <AxisLeft yScale={yScale} />
          <AxisBottom xScale={xScale} innerHeight={innerHeight} tickFormat={xAxisTickFormat} />
          <Marks
          data={filteredData}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          tooltipFormat={xAxisTickFormat}
        />
   			</g>
      </svg>
     <div class="slider-container">
        <Slider
          minDay={minDay}
          maxDay={maxDay}
          dayStep={dayStep}
          day={day}
          onSlide={setDay}
          sliderHidden={sliderHidden}
        />
      </div>
     
    </>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
